@@ -20,13 +20,21 @@
 #define CALLBACKS_H
 
 #include <gtk/gtk.h>
+#include "config.h"
 
 gboolean entry_focus_in_event(GtkWidget *widget, GdkEventFocus *event, gpointer data);
 gboolean entry_focus_out_event(GtkWidget *widget, GdkEventFocus *event, gpointer data);
+#ifndef HAVE_GTK_2_10
 void keep_running_toggled(GtkToggleButton *button, gpointer user_data);
+#endif
 void about_button_clicked(GtkWidget *widget, gpointer data);
 void start_button_clicked(GtkWidget *widget, gpointer data);
 void close_button_clicked(GtkWidget *widget, gpointer data);
 gboolean delete_event(GtkWidget *widget, GdkEvent *event, gpointer user_data);
+#ifdef HAVE_GTK_2_10
+void quicksynergy_quit(GtkWidget *widget, gpointer data);
+void show_main_window(GtkWidget *widget, gpointer data);
+void status_icon_popup(GtkStatusIcon *status_icon, guint button, guint activate_time, gpointer user_data);
+#endif
 
 #endif
