@@ -31,11 +31,12 @@ int selfunc(const struct dirent *ep) {
     return 0;
 }
 
-pid_t get_pid_by_name(char *command) {
+pid_t get_pid_by_name(const char *command) {
     FILE *fp;
     struct dirent **proclist;
     char filename[128], l[128], opt[128], val[128];
     int n, i;
+    pid_t pid = 0;
 
     if((n = scandir("/proc", &proclist, selfunc, alphasort)) != -1) {
         for(i = 0; i < n; i++) {
@@ -51,13 +52,22 @@ pid_t get_pid_by_name(char *command) {
 
                     if(!strcmp(opt, "Name:"))
                         if(!strcmp(val, command))
-							return atoi(proclist[i]->d_name);
+                        {
+                            pid = (pid_t)atoi(proclist[i]->d_name);
+                            break;
+                        }
                 }
 
                 fclose(fp);
             }
         }
+
+        /* We need to deallocate the memory used to build the list of dirs */
+        for(i = 0; i < n; i++) {
+            free(proclist[i]);
+        }
+        free(proclist);
     }
-	
-	return 0;
+    
+    return pid;
 }
