@@ -21,6 +21,6 @@
 
 #include <sys/types.h>
 
-pid_t get_pid_by_name(char *command);
-	
+pid_t get_pid_by_name(const char *command);
+    
 #endif
