@@ -21,11 +21,8 @@
 
 #include <gtk/gtk.h>
 
-void load_config(GtkWidget *above_entry, GtkWidget *below_entry,
-        GtkWidget *left_entry, GtkWidget *right_entry);
-void save_config(GtkWidget *above_entry, GtkWidget *below_entry,
-        GtkWidget *left_entry, GtkWidget *right_entry);
-void save_synergy_config(GtkWidget *above_entry, GtkWidget *below_entry,
-        GtkWidget *left_entry, GtkWidget *right_entry);
+void load_config();
+void save_config();
+void save_synergy_config();
 
 #endif /* SYNERGY_CONFIG_H */
